==> assert-is-enumerable-property-in-0.0.3.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# isEnumerablePropertyIn

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] [![dependencies][dependencies-image]][dependencies-url]

> Test if an object's own or inherited property is enumerable.

<section class="installation">

## Installation

```bash
npm install @stdlib/assert-is-enumerable-property-in
```

</section>

<section class="usage">

## Usage

```javascript
var isEnumerablePropertyIn = require( '@stdlib/assert-is-enumerable-property-in' );
```

#### isEnumerablePropertyIn( value, property )

Returns a `boolean` indicating if a `value` has an enumerable `property`.

<!-- eslint-disable no-restricted-syntax -->

```javascript
var defineProperty = require( '@stdlib/utils-define-property' );

var bool;
var obj;

function Foo() {
    this.foo = 'bar';
    return this;
}

defineProperty( Foo.prototype, 'beep', {
    'configurable': true,
    'enumerable': true,
    'writable': true,
    'value': true
});

defineProperty( Foo.prototype, 'boop', {
    'configurable': true,
    'enumerable': false,
    'writable': true,
    'value': true
});

obj = new Foo();

bool = isEnumerablePropertyIn( obj, 'foo' );
// returns true

bool = isEnumerablePropertyIn( obj, 'beep' );
// returns true

bool = isEnumerablePropertyIn( obj, 'boop' );
// returns false
```

</section>

<!-- /.usage -->

<section class="notes">

## Notes

-   Value arguments other than `null` or `undefined` are coerced to `objects`.

    ```javascript
    var bool = isEnumerablePropertyIn( 'beep', 'toString' );
    // returns false
    ```

-   Property arguments are coerced to `strings`.

    ```javascript
    var obj = {
        'null': 'foo'
    };

    var bool = isEnumerablePropertyIn( obj, null );
    // returns true
    ```

</section>

<!-- /.notes -->

<section class="examples">

## Examples

<!-- eslint-disable object-curly-newline -->

<!-- eslint no-undef: "error" -->

```javascript
var isEnumerablePropertyIn = require( '@stdlib/assert-is-enumerable-property-in' );

var bool = isEnumerablePropertyIn( { 'a': 'b' }, 'a' );
// returns true

bool = isEnumerablePropertyIn( [ 'a' ], 0 );
// returns true

bool = isEnumerablePropertyIn( { 'null': false }, null );
// returns true

bool = isEnumerablePropertyIn( { '[object Object]': false }, {} );
// returns true

bool = isEnumerablePropertyIn( {}, 'toString' );
// returns false

bool = isEnumerablePropertyIn( {}, 'hasOwnProperty' );
// returns false

bool = isEnumerablePropertyIn( [ 'a' ], 'length' );
// returns false

bool = isEnumerablePropertyIn( null, 'a' );
// returns false

bool = isEnumerablePropertyIn( void 0, 'a' );
// returns false
```

</section>

<!-- /.examples -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2021. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/assert-is-enumerable-property-in.svg
[npm-url]: https://npmjs.org/package/@stdlib/assert-is-enumerable-property-in

[test-image]: https://github.com/stdlib-js/assert-is-enumerable-property-in/actions/workflows/test.yml/badge.svg
[test-url]: https://github.com/stdlib-js/assert-is-enumerable-property-in/actions/workflows/test.yml

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/assert-is-enumerable-property-in/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/assert-is-enumerable-property-in?branch=main

[dependencies-image]: https://img.shields.io/david/stdlib-js/assert-is-enumerable-property-in
[dependencies-url]: https://david-dm.org/stdlib-js/assert-is-enumerable-property-in/main

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/assert-is-enumerable-property-in/main/LICENSE

</section>

<!-- /.links -->

==> assert-is-enumerable-property-in-0.0.5.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# isEnumerablePropertyIn

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] [![dependencies][dependencies-image]][dependencies-url]

> Test if an object's own or inherited property is enumerable.

<section class="installation">

## Installation

```bash
npm install @stdlib/assert-is-enumerable-property-in
```

</section>

<section class="usage">

## Usage

```javascript
var isEnumerablePropertyIn = require( '@stdlib/assert-is-enumerable-property-in' );
```

#### isEnumerablePropertyIn( value, property )

Returns a `boolean` indicating if a `value` has an enumerable `property`.

<!-- eslint-disable no-restricted-syntax -->

```javascript
var defineProperty = require( '@stdlib/utils-define-property' );

var bool;
var obj;

function Foo() {
    this.foo = 'bar';
    return this;
}

defineProperty( Foo.prototype, 'beep', {
    'configurable': true,
    'enumerable': true,
    'writable': true,
    'value': true
});

defineProperty( Foo.prototype, 'boop', {
    'configurable': true,
    'enumerable': false,
    'writable': true,
    'value': true
});

obj = new Foo();

bool = isEnumerablePropertyIn( obj, 'foo' );
// returns true

bool = isEnumerablePropertyIn( obj, 'beep' );
// returns true

bool = isEnumerablePropertyIn( obj, 'boop' );
// returns false
```

</section>

<!-- /.usage -->

<section class="notes">

## Notes

-   Value arguments other than `null` or `undefined` are coerced to `objects`.

    ```javascript
    var bool = isEnumerablePropertyIn( 'beep', 'toString' );
    // returns false
    ```

-   Property arguments are coerced to `strings`.

    ```javascript
    var obj = {
        'null': 'foo'
    };

    var bool = isEnumerablePropertyIn( obj, null );
    // returns true
    ```

</section>

<!-- /.notes -->

<section class="examples">

## Examples

<!-- eslint-disable object-curly-newline -->

<!-- eslint no-undef: "error" -->

```javascript
var isEnumerablePropertyIn = require( '@stdlib/assert-is-enumerable-property-in' );

var bool = isEnumerablePropertyIn( { 'a': 'b' }, 'a' );
// returns true

bool = isEnumerablePropertyIn( [ 'a' ], 0 );
// returns true

bool = isEnumerablePropertyIn( { 'null': false }, null );
// returns true

bool = isEnumerablePropertyIn( { '[object Object]': false }, {} );
// returns true

bool = isEnumerablePropertyIn( {}, 'toString' );
// returns false

bool = isEnumerablePropertyIn( {}, 'hasOwnProperty' );
// returns false

bool = isEnumerablePropertyIn( [ 'a' ], 'length' );
// returns false

bool = isEnumerablePropertyIn( null, 'a' );
// returns false

bool = isEnumerablePropertyIn( void 0, 'a' );
// returns false
```

</section>

<!-- /.examples -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2021. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/assert-is-enumerable-property-in.svg
[npm-url]: https://npmjs.org/package/@stdlib/assert-is-enumerable-property-in

[test-image]: https://github.com/stdlib-js/assert-is-enumerable-property-in/actions/workflows/test.yml/badge.svg
[test-url]: https://github.com/stdlib-js/assert-is-enumerable-property-in/actions/workflows/test.yml

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/assert-is-enumerable-property-in/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/assert-is-enumerable-property-in?branch=main

[dependencies-image]: https://img.shields.io/david/stdlib-js/assert-is-enumerable-property-in.svg
[dependencies-url]: https://david-dm.org/stdlib-js/assert-is-enumerable-property-in/main

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://gitter.im/stdlib-js/stdlib/

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/assert-is-enumerable-property-in/main/LICENSE

</section>

<!-- /.links -->
